@@ -255,21 +255,25 @@ def PlotHydrosphereProps(PlanetList, Params):
                 indsLiq, indsI, indsIwet, indsII, indsIIund, indsIII, indsIIIund, indsV, indsVund, indsVI, indsVIund, \
                 indsClath, indsClathWet, _, indsSilLiq, _, _, _, _, _, _ = GetPhaseIndices(Planet.phase)
 
+                indsIce = np.sort(np.concatenate((indsI, indsIwet, indsII, indsIIund, indsIII, indsIIIund,
+                                                  indsV, indsVund, indsVI, indsVIund, indsClath, indsClathWet)))
+
                 if DO_SIGS:
                     # Plot electrical conductivity vs. depth for hydrosphere
-                    if np.size(indsLiq) > 0:
-                        sigma_Sm = Planet.sigma_Sm[indsLiq]
-                        z_km = Planet.z_m[indsLiq]/1e3
-                    else:
-                        sigma_Sm = Planet.sigma_Sm[:Planet.Steps.nHydro]
-                        z_km = Planet.z_m[:Planet.Steps.nHydro]/1e3
-                    axsigz.plot(sigma_Sm[sigma_Sm > sigCutoff_Sm], z_km[sigma_Sm > sigCutoff_Sm],
+                    sigma_Sm = Planet.sigma_Sm[:Planet.Steps.nHydro]
+                    z_km = Planet.z_m[:Planet.Steps.nHydro]/1e3
+                    if not FigMisc.SHOW_ICE_CONDUCT:
+                        sigma_Sm[indsIce] = np.nan
+                    if Planet.Do.POROUS_ICE:
+                        indsWet = np.sort(np.concatenate((indsIwet, indsII, indsIII, indsV, indsVI, indsClathWet)))
+                        sigma_Sm[indsWet] = Planet.sigma_Sm[indsWet]
+                    sigma_Sm[sigma_Sm < sigCutoff_Sm] = np.nan
+                    z_km[sigma_Sm < sigCutoff_Sm] = np.nan
+                    axsigz.plot(sigma_Sm, z_km,
                                 color=thisColor, linewidth=thisLW,
                                 linestyle=Style.LS[Planet.Ocean.comp])
 
                 if DO_SOUNDS:
-                    indsIce = np.sort(np.concatenate((indsI, indsIwet, indsII, indsIIund, indsIII, indsIIIund,
-                                                      indsV, indsVund, indsVI, indsVIund, indsClath, indsClathWet)))
                     # Plot sound speeds in ocean and ices vs. depth in hydrosphere
                     indsHydro = np.sort(np.concatenate((indsIce, indsLiq)))
                     VPice = Planet.Seismic.VP_kms[indsHydro]
@@ -314,14 +318,16 @@ def PlotHydrosphereProps(PlanetList, Params):
             Padj = 0.03*np.abs(np.diff(axPrho.get_ylim())[0])
 
             if phase == 0:
-                loc = np.where(Pall_MPa == np.min(Pall_MPa[phases == 0]))[0]
-                if np.size(loc) > 1: loc = loc[0]
+                # loc = np.where(Pall_MPa == np.min(Pall_MPa[phases == 0]))[0]
+                # if np.size(loc) > 1: loc = loc[0]
+                rhoLoc_kgm3 = np.mean(rhoAll_kgm3[phases == 0])
+                Ploc_MPa = np.mean(Pall_MPa[phases == 0])
                 # Shift label closer in the case of a thin ocean, where the curve will be short
                 if np.all([Planet.THIN_OCEAN for Planet in PlanetList]):
                     adj2 = -adj
                 else:
                     adj2 = 0
-                axPrho.text(rhoAll_kgm3[loc] + 3*adj + adj2, (Pall_MPa[loc] + Padj)*FigLbl.PmultHydro,
+                axPrho.text(rhoLoc_kgm3 + adj2, Ploc_MPa*FigLbl.PmultHydro,
                             'liquid', ha='center', va='center', fontsize=FigLbl.TS_hydroLabels)
             else:
                 if phase == Constants.phaseClath:
